#!/bin/bash
# packager         : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# source location  : http://www.geany.org/
# last revised     : 07.01.2011

softname='geany'
softversion='0.20'
packageversion='70.1'

arch='i686'
cpu='i686'

prefix=/usr

#
# log
#
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.bz2"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://download.geany.org/$softname-$softversion.tar.bz2

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps/
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
     |-----handy-ruler------------------------------------------------------|
geany: geany - A text editor using the GTK2 toolkit
geany:
geany: Geany is a text editor using the GTK2 toolkit with basic features of an
geany: ntegrated development environment. It was developed to provide a small
geany: and fast IDE, which has only a few dependencies from other packages.
geany: It supports many filetypes and has some nice features.
geany:
geany:
geany:
geany:
geany:
EOF

# check if source is present
if [ -f $softname-$softversion.tar.bz2 ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xvf $srcpkg
cd $src

# build
    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

    ./configure \
      --prefix=$prefix \
      --mandir=/usr/man \
      --docdir=/usr/doc/$softname-$softversion \
      --htmldir=/usr/doc/$softname-$softversion \
      --enable-static="no" \
      --enable-shared="yes" \
      --build=$arch-slackware-linux \
      --host=$arch-slackware-linux \
      --target=$arch-slackware-linux

    make
    make install DESTDIR=$dest
    
# make the .desktop file
cat <<"EOF" > $dest/usr/share/applications/geany.desktop
[Desktop Entry]
Encoding=UTF-8
Name=Geany
GenericName=Integrated Development Environment
GenericName[de]=Integrierte Entwicklungsumgebung
Comment=A fast and lightweight IDE using GTK2
Comment[de]=Eine kleine und schnelle integrierte Entwicklungsumgebung
Comment[pl]=Szybkie i lekkie IDE korzystające z GTK+2
Exec=geany %F
Icon=geany
Terminal=false
Type=Application
Categories=Application;GTK;Development;IDE;
MimeType=text/x-python;text/x-perl;text/x-pascal;text/x-java;text/x-tcl;text/x-csrc;text/x-chdr;text/x-c++hdr;text/x-c++src;application/x-perl;application/x-python;application/x-shellscript;text/x-sql;text/x-latex;text/x-makefile;application/x-desktop;text/x-asm;
EOF
	
# add 'default' files
    #cp -a \
      AUTHORS COPYING ChangeLog INSTALL NEWS README TODO\
      $dest/usr/doc/$softname-$softversion

# Strip Executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# Make the package freedesktop compliant
cd $dest/usr/share/icons/hicolor/48x48/apps/
ln -s ../../../../pixmaps/$softname.png  $softname.png

# ZenBuild
cp $buildir/build-$softname.sh $dest/$prefix/src/$softname-$softversion

# Compress Man Pages
mv $dest/$prefix/share/man $dest/$prefix/
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 640 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;
find . -type d -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

# dep file
echo -e "atk,cairo,expat,fontconfig,freetype,gcc,gcc-g++,glib2,\
gtk+2,libX11,libXau,libXcomposite,libXcursor,libXdamage,libXdmcp,\
libXext,libXfixes,libXi,libXinerama,libXrandr,libXrender,libpng,\
libxcb,pango,pixman,zlib" > $package.dep

# generate source file
echo http://zenwalk.pinguix.com/user-accounts/bip/ISO/xap/geany/source/build-geany.sh > $package.src
echo $source >>$package.src

# erase source
rm -rf $src
rm -rf $dest

# log
) 2>&1 | tee "$softname-$softversion-build.log"
